weblogolib._cgi.Field

Package weblogolib :: Module _cgi :: Class Field |

# Class Field

source code

    object --+
             |
            Field

    A representation of an HTML form field.

Instance Methods
__init__(self, name, default=None, conversion=None, options=None, errmsg="Illegal value.") x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
get_value(self) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, name, default=None, conversion=None, options=None, errmsg="Illegal value.") (Constructor) | source code
    x.__init__(...) initializes x; see x.__class__.__doc__ for signature
Overrides: object.__init__ (inherited documentation)